@@ -10,7 +10,6 @@
 import uuid
 import re
 import tempfile
-import json
 import warnings
 import time
 import dateutil.parser
@@ -22,6 +21,7 @@ from itertools import chain, cycle
 from mimetypes import guess_type
 from email.utils import parseaddr
 
+import simplejson as json
 from babel.dates import parse_date
 from nereid import (
     request, abort, render_template, login_required, url_for, redirect,
@@ -55,9 +55,18 @@ PROGRESS_STATES = [
     ('Planning', 'Planning'),
     ('In Progress', 'In Progress'),
     ('Review', 'Review/QA'),
+    ('Done', 'Done'),
 ]
 
 
+def request_wants_json():
+    best = request.accept_mimetypes \
+        .best_match(['application/json', 'text/html'])
+    return best == 'application/json' and \
+        request.accept_mimetypes[best] > \
+        request.accept_mimetypes['text/html']
+
+
 class WebSite:
     """
     Website
@@ -398,6 +407,8 @@ class Project:
             value['hours'] = self.hours
             value['effort'] = self.effort
             value['total_effort'] = self.total_effort
+            value['project'] = self and self.id
+            value['created_by'] = self.created_by and self.created_by._json()
         else:
             value['all_participants'] = [
                 participant._json() for participant in self.all_participants
@@ -415,6 +426,7 @@ class Project:
             'type': self.type,
             'objectType': self.__name__,
         }
+        rv.update(self.serialize())
         if self.type == 'project':
             rv['url'] = url_for(
                 'project.work.render_project', project_id=self.id
@@ -1072,7 +1084,7 @@ class Project:
             'project/global-task-list.jinja',
             active_type_name='render_task_list', counts=counts,
             state_filter=state, tasks_by_state=tasks_by_state,
-            states=PROGRESS_STATES
+            states=PROGRESS_STATES[:-1]
         )
 
     @classmethod
@@ -1095,7 +1107,10 @@ class Project:
 
         if request.is_xhr:
             response = cls.serialize(task)
-            response['comments'] = [comment._json() for comment in comments]
+            with Transaction().set_context(task=task_id):
+                response['comments'] = [
+                    comment._json() for comment in comments
+                ]
             return jsonify(response)
 
         return render_template(
@@ -1527,7 +1542,7 @@ class Project:
             'project/tasks-by-employee.jinja',
             tasks_by_employee_by_state=tasks_by_employee_by_state,
             employees=employees,
-            states=PROGRESS_STATES,
+            states=PROGRESS_STATES[:-1],
         )
 
     @classmethod
@@ -1675,15 +1690,16 @@ class Project:
         attached_file = request.files["file"]
         resource = '%s,%d' % (cls.__name__, work.id)
 
+        filename = attached_file.filename
         if Attachment.search([
-            ('name', '=', attached_file.filename),
+            ('name', '=', filename),
             ('resource', '=', resource)
         ]):
-            flash(
-                'File already exists with same name, please choose another ' +
-                'file or rename this file to upload !!'
+            # try to create a unique filename
+            filename, extension = filename.split('.', 1)
+            filename = '%s-%d.%s' % (
+                filename, time.time(), extension
             )
-            return redirect(request.referrer)
 
         data = {
             'resource': resource,
@@ -1700,16 +1716,18 @@ class Project:
         else:
             data.update({
                 'data': attached_file.stream.read(),
-                'name': attached_file.filename,
+                'name': filename,
                 'type': 'data'
             })
 
-        Attachment.create([data])
+        attachment = Attachment.create([data])
 
-        if request.is_xhr:
-            return jsonify({
-                'success': True
-            })
+        if request.is_xhr or request_wants_json():
+            with Transaction().set_context(task=work.id):
+                return jsonify({
+                    'success': True,
+                    'data': attachment._json(),
+                })
 
         flash("Attachment added to %s" % work.rec_name)
         return redirect(request.referrer)
@@ -1734,7 +1752,7 @@ class Project:
             'comment': request.form['comment']
         }
 
-        updatable_attrs = ['state', 'progress_state']
+        updatable_attrs = ['progress_state']
         new_participant_ids = []
         current_participant_ids = [p.id for p in task.participants]
         post_attrs = [request.form.get(attr, None) for attr in updatable_attrs]
@@ -1746,6 +1764,11 @@ class Project:
                 if getattr(task, attr) != request.form.get(attr, None):
                     task_changes[attr] = request.form[attr]
 
+            if task_changes.get('progress_state') == 'Done':
+                task_changes['state'] = 'done'
+            else:
+                task_changes['state'] = 'opened'
+
             new_assignee_id = request.form.get('assigned_to', None, int)
             if not new_assignee_id is None:
                 if (new_assignee_id and
@@ -2083,7 +2106,9 @@ class Project:
         page = request.args.get('page', 1, int)
 
         domain = [('project', '=', self.id)]
-        activities = Pagination(Activity, domain, page, 20)
+        activities = Pagination(
+            Activity, domain, page, request.args.get('limit', 20, type=int)
+        )
         items = filter(
             None, map(lambda activity: activity.serialize(), activities)
         )
@@ -2302,6 +2327,7 @@ class ProjectHistory(ModelSQL, ModelView):
             "comment": self.comment,
             "new_state": self.new_state,
             "new_progress_state": self.new_progress_state,
+            "previous_progress_state": self.previous_progress_state,
             "new_assignee": (
                 self.new_assigned_to._json() if self.new_assigned_to
                     else None
@@ -2502,7 +2528,7 @@ class ProjectWorkCommit(ModelSQL, ModelView):
             "displayName": self.commit_message,
             "repository": self.repository,
             "repository_url": self.repository_url,
-            "commit_timestamp": self.commit_timestamp,
+            "commit_timestamp": self.commit_timestamp.isoformat(),
             "commit_id": self.commit_id,
         }
 
@@ -2680,6 +2706,20 @@ class Activity:
         'project.work', 'Project', domain=[('type', '=', 'project')]
     )
 
+    @classmethod
+    def get_activity_stream_domain(cls):
+        '''
+        Returns the domain to get activity stream of project where current user
+        is participant
+        '''
+        return [
+            'OR', [
+                ('project.participants', '=', request.nereid_user.id),
+            ], [
+                ('actor', '=', request.nereid_user.id)
+            ]
+        ]
+
 
 class Attachment:
     '''
@@ -2688,9 +2728,18 @@ class Attachment:
     __name__ = "ir.attachment"
 
     def _json(self):
-        return {
+        rv = {
             'create_date': self.create_date.isoformat(),
             "objectType": self.__name__,
             "id": self.id,
             "updatedBy": self.uploaded_by._json(),
+            "displayName": self.name,
+            "description": self.description,
         }
+        if has_request_context():
+            rv['downloadUrl'] = url_for(
+                'project.work.download_file',
+                attachment_id=self.id,
+                task=Transaction().context.get('task'),
+            )
+        return rv
